(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 13.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[     23903,        531]
NotebookOptionsPosition[     22306,        499]
NotebookOutlinePosition[     22881,        520]
CellTagsIndexPosition[     22838,        517]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[TextData[StyleBox["Last checked 21 April, 2023",
 CellFrame->True,
 Background->GrayLevel[0.849989]]], "Text",
 CellFrame->True,
 CellChangeTimes->{{3.851321730299733*^9, 3.851321747924562*^9}, 
   3.8513218075505953`*^9, {3.890897811719871*^9, 3.890897826726935*^9}, {
   3.890973965108789*^9, 3.8909739653874283`*^9}, {3.891080224224403*^9, 
   3.891080224709962*^9}},
 TextAlignment->Left,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"38ec253e-1b44-4e36-a8c5-d557cead260a"],

Cell["Chapter 9, Section 9.4, Figure 9.12", "Section",
 CellChangeTimes->{{3.8516824850054398`*^9, 3.8516824897129374`*^9}, {
  3.855575679475662*^9, 3.855575716165421*^9}, {3.8870115919770947`*^9, 
  3.8870116202947073`*^9}, {3.887448039929792*^9, 
  3.887448042819315*^9}},ExpressionUUID->"66d6ba2b-47f8-4d2b-a950-\
7052c61932c1"],

Cell[TextData[{
 "Define a function ",
 StyleBox["JacobiConstantY0",
  FontWeight->"Bold"],
 " using Eq.(3.39) to give the value of the Jacobi Constant for given values \
of the coordinates ",
 StyleBox["(x,y=0) ",
  FontWeight->"Bold"],
 "and secondary mass ",
 StyleBox["\[Mu]",
  FontWeight->"Bold"],
 ".  This is in a system where the sum of the masses is unity (the two masses \
are ",
 StyleBox["1-\[Mu]",
  FontWeight->"Bold"],
 " and ",
 StyleBox["\[Mu]",
  FontWeight->"Bold"],
 "), the mean motion is unity and the separation of the two masses is the \
unit of distance.  We are setting ",
 StyleBox["y = 0",
  FontSlant->"Italic"],
 " because we are interested in finding the roots in order to determine how \
close the particle can get to the secondary mass due to the forbidden region. \
In all the calculations we are taking \[Mu] = 0.001."
}], "Text",
 CellFrame->True,
 CellChangeTimes->{{3.851855840359335*^9, 3.851855841844705*^9}, 
   3.851856265777122*^9, {3.8555757340758543`*^9, 3.855575742550215*^9}, {
   3.855575793355549*^9, 3.855575912424005*^9}, {3.855576001478415*^9, 
   3.855576003144066*^9}, {3.855576068768293*^9, 3.855576096248996*^9}, {
   3.887452248975576*^9, 3.887452387128456*^9}, {3.887454448874773*^9, 
   3.887454468089643*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"db95312e-36a0-492f-b058-787d66ce8ffa"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"JacobiConstantY0", "[", 
    RowBox[{"x_", ",", "\[Mu]_"}], "]"}], ":=", " ", 
   RowBox[{"2", "*", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{"x", "^", "2"}], " ", ")"}], "/", "2"}], " ", "+", " ", 
      RowBox[{"\[Mu]", "/", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], " ", "+", " ", "\[Mu]", " ", "+", " ", "x"}], 
           ")"}], "^", "2"}], " ", ")"}], "^", 
        RowBox[{"(", 
         RowBox[{"1", "/", "2"}], ")"}]}]}], " ", "+", " ", "\n", "     ", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"1", " ", "-", " ", "\[Mu]"}], ")"}], "/", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"\[Mu]", " ", "+", " ", "x"}], ")"}], "^", "2"}], " ", 
         ")"}], "^", 
        RowBox[{"(", 
         RowBox[{"1", "/", "2"}], ")"}]}]}]}], ")"}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.8553956040822*^9, 3.8553956257307997`*^9}, {
  3.855395670092389*^9, 3.855395674629765*^9}, {3.855396998229671*^9, 
  3.855397012135157*^9}, {3.8553973528860893`*^9, 3.855397356902308*^9}, {
  3.887452396952755*^9, 3.887452415912978*^9}, {3.887452453553446*^9, 
  3.887452456207849*^9}},
 CellLabel->"In[1]:=",ExpressionUUID->"9d139eb4-71d0-4837-8f10-8feab0fa82b4"],

Cell[BoxData[
 RowBox[{
  RowBox[{"closest", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"cv", ",", 
       RowBox[{"First", "[", 
        RowBox[{
         RowBox[{"0.999", "-", "x"}], "/.", 
         RowBox[{"NSolve", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"JacobiConstantY0", "[", 
             RowBox[{"x", ",", "0.001"}], "]"}], "==", "cv"}], ",", 
           "PositiveReals"}], "]"}]}], "]"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"cv", ",", "3.04", ",", "3.48", ",", "0.001"}], "}"}]}], 
    "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.887452543576119*^9, 3.8874525881553097`*^9}, {
   3.8874526411202793`*^9, 3.887452652503171*^9}, {3.8874526951045017`*^9, 
   3.887452696138961*^9}, {3.887452770102475*^9, 3.8874527756218643`*^9}, {
   3.887452810288962*^9, 3.887452810601741*^9}, {3.8874528646454372`*^9, 
   3.887452931529327*^9}, {3.887452996763887*^9, 3.887453022727881*^9}, {
   3.88745308140823*^9, 3.8874531287163963`*^9}, 3.887453391139278*^9, 
   3.887454479220372*^9, {3.88745572150369*^9, 3.887455724724545*^9}},
 CellLabel->"In[2]:=",ExpressionUUID->"f530a849-d9f6-4f63-9019-36a53df1f7c4"],

Cell["Define the axis labels.", "Text",
 CellFrame->True,
 CellChangeTimes->{{3.869373084037505*^9, 3.869373204667523*^9}, {
  3.869552502127846*^9, 3.869552527987165*^9}, {3.8695525676926813`*^9, 
  3.869552627902935*^9}, {3.869552688038094*^9, 3.8695527321988773`*^9}, {
  3.86955276584477*^9, 3.8695527789835157`*^9}, {3.869552853609722*^9, 
  3.8695529191526623`*^9}, {3.869553047085703*^9, 3.869553087120385*^9}, {
  3.870607952402626*^9, 3.870607986048612*^9}, {3.870608112694354*^9, 
  3.870608186135066*^9}, {3.870608226185451*^9, 3.8706082321707907`*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"6a483d6b-d5b3-4a16-b3c9-df1c78ec9654"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"xlabel", "=", "\"\<\!\(\*TemplateBox[<|\"boxes\" -> FormBox[
SubscriptBox[
StyleBox[\"C\", \"TI\"], \"J\"], TraditionalForm], \"errors\" -> {}, \
\"input\" -> \"C_{\\\\rm{J}}\", \"state\" -> \
\"Boxes\"|>,\"TeXAssistantTemplate\"]\)\>\""}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ylabel", "=", "\"\<\!\(\*TemplateBox[<|\"boxes\" -> FormBox[
SubscriptBox[
StyleBox[\"d\", \"TI\"], \"min\"], TraditionalForm], \"errors\" -> {}, \
\"input\" -> \"d_{\\\\rm min}\", \"state\" -> \
\"Boxes\"|>,\"TeXAssistantTemplate\"]\)\>\""}], ";"}]}], "Input",
 CellChangeTimes->{{3.851338850796014*^9, 3.851338856475478*^9}, {
  3.851339056483313*^9, 3.851339071079105*^9}, {3.8790751708185472`*^9, 
  3.879075193961151*^9}, {3.8790752823156977`*^9, 3.879075295960511*^9}, {
  3.8846966972447853`*^9, 3.884696730405851*^9}, {3.88493529231481*^9, 
  3.8849353055043716`*^9}, {3.884941395113693*^9, 3.8849414110124063`*^9}, {
  3.8849475793505383`*^9, 3.884947581732547*^9}, {3.887354080424882*^9, 
  3.887354102034628*^9}},
 CellLabel->"In[3]:=",ExpressionUUID->"15bb367d-95ae-4deb-977a-64138d3c7055"],

Cell["Set the colour to be used for the plot.", "Text",
 CellFrame->True,
 CellChangeTimes->{{3.878562591887006*^9, 3.878562613471806*^9}, {
  3.878645977794298*^9, 3.878646003488901*^9}, {3.878646081324325*^9, 
  3.878646113633102*^9}, {3.884607227808136*^9, 3.884607228482621*^9}, {
  3.887454139911439*^9, 3.88745414714042*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"a2bc5286-e70f-4a92-99dd-da046c3645b3"],

Cell[BoxData[
 RowBox[{
  RowBox[{"color1", "=", 
   RowBox[{"RGBColor", "[", 
    RowBox[{"0.368417`", ",", "0.506779`", ",", "0.709798`"}], "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.884607205132513*^9, 3.884607206710265*^9}, {
  3.887454152256719*^9, 3.8874541527655783`*^9}},
 CellLabel->"In[5]:=",ExpressionUUID->"a4d0dc5a-8059-4108-ac8e-50fd2c4c854c"],

Cell[TextData[{
 "Plot the closest distance, ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    TemplateBox[<|"boxes" -> FormBox[
        SubscriptBox[
         StyleBox["d", "TI"], "min"], TraditionalForm], "errors" -> {}, 
      "input" -> "d_{\\rm min}", "state" -> "Boxes"|>,
     "TeXAssistantTemplate"], " "}], TraditionalForm]],ExpressionUUID->
  "6112c58c-97a9-4639-bc45-30e329404da5"],
 ", as a function of the value of the Jacobi constant, ",
 Cell[BoxData[
  FormBox[
   TemplateBox[<|"boxes" -> FormBox[
       SubscriptBox[
        StyleBox["C", "TI"], "J"], TraditionalForm], "errors" -> {}, "input" -> 
     "C_{\\rm J}", "state" -> "Boxes"|>,
    "TeXAssistantTemplate"], TraditionalForm]],ExpressionUUID->
  "8fafa4d1-705d-479a-b22b-c2da6c0149d9"],
 ".  This is Fig.9.12."
}], "Text",
 CellFrame->True,
 CellChangeTimes->{{3.878562591887006*^9, 3.878562613471806*^9}, {
  3.878645977794298*^9, 3.878646003488901*^9}, {3.878646081324325*^9, 
  3.878646113633102*^9}, {3.884607227808136*^9, 3.884607228482621*^9}, {
  3.887454139911439*^9, 3.88745414714042*^9}, {3.887454372494619*^9, 
  3.88745442586102*^9}, {3.887454561824052*^9, 3.887454599308948*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"dc79387d-4d83-4e82-b728-78f4965401e7"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ListPlot", "[", 
  RowBox[{"closest", ",", 
   RowBox[{"Joined", "->", "True"}], ",", 
   RowBox[{"PlotStyle", "->", 
    RowBox[{"Directive", "[", 
     RowBox[{"color1", ",", 
      RowBox[{"Thickness", "[", "0.005", "]"}]}], "]"}]}], ",", 
   RowBox[{"PlotRange", "->", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"3.03", ",", "3.48"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"0.065", ",", "0.35"}], "}"}]}], "}"}]}], ",", 
   RowBox[{"FrameTicks", "->", "Automatic"}], ",", 
   RowBox[{"Frame", "->", "True"}], ",", " ", 
   RowBox[{"FrameLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"xlabel", ",", 
      RowBox[{"Rotate", "[", 
       RowBox[{"ylabel", ",", 
        RowBox[{
         RowBox[{"-", "\[Pi]"}], "/", "2"}]}], "]"}]}], "}"}]}], ",", 
   RowBox[{"FrameStyle", "->", 
    RowBox[{"Thickness", "[", "0.004", "]"}]}], ",", "\[IndentingNewLine]", 
   RowBox[{"LabelStyle", "\[Rule]", 
    RowBox[{"Directive", "[", 
     RowBox[{
      RowBox[{"FontFamily", "\[Rule]", "\"\<Times\>\""}], ",", 
      RowBox[{"FontSize", "\[Rule]", "16"}]}], "]"}]}], ",", 
   RowBox[{"AxesOrigin", "->", 
    RowBox[{"{", 
     RowBox[{"3.05", ",", "0.065"}], "}"}]}], ",", 
   RowBox[{"PlotRangePadding", "->", "None"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.887453033348649*^9, 3.887453037232008*^9}, {
   3.887453102391827*^9, 3.887453106306364*^9}, {3.887453162198896*^9, 
   3.887453169950816*^9}, {3.8874532012407627`*^9, 3.887453287683949*^9}, {
   3.887453411988014*^9, 3.887453432506466*^9}, 3.88745411923925*^9, {
   3.887454181131874*^9, 3.887454233464671*^9}, {3.8874542832355013`*^9, 
   3.887454303709642*^9}, 3.8874547777193317`*^9, {3.887523747745764*^9, 
   3.8875237627686653`*^9}, {3.887523813470044*^9, 3.8875238424640102`*^9}},
 CellLabel->"In[6]:=",ExpressionUUID->"2be82904-b6a6-4717-8d2d-1db439c5c7d9"],

Cell[BoxData[
 GraphicsBox[{{}, {{}, {}, 
    {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.007333333333333334], 
     Thickness[0.005], LineBox[CompressedData["
1:eJwt1XlcTOv/APBBdM5zcENIQgi5Zc9ybc9HhaTIeonIXiklJCF7V9mXyJpd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      "]]}}, {{}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{3.05, 0.065},
  DisplayFunction->Identity,
  Frame->{{True, True}, {True, True}},
  FrameLabel->{{
     FormBox[
      TagBox[
       RotationBox[
       "\"\\!\\(\\*TemplateBox[<|\\\"boxes\\\" -> \
FormBox[SubscriptBox[StyleBox[\\\"d\\\", \\\"TI\\\"], \\\"min\\\"], \
TraditionalForm], \\\"errors\\\" -> {}, \\\"input\\\" -> \\\"d_{\\\\\\\\rm \
min}\\\", \\\"state\\\" -> \
\\\"Boxes\\\"|>,\\\"TeXAssistantTemplate\\\"]\\)\"", 
        BoxRotation -> -1.5707963267948966`], HoldForm], TraditionalForm], 
     None}, {
     FormBox[
      TagBox[
      "\"\\!\\(\\*TemplateBox[<|\\\"boxes\\\" -> \
FormBox[SubscriptBox[StyleBox[\\\"C\\\", \\\"TI\\\"], \\\"J\\\"], \
TraditionalForm], \\\"errors\\\" -> {}, \\\"input\\\" -> \
\\\"C_{\\\\\\\\rm{J}}\\\", \\\"state\\\" -> \
\\\"Boxes\\\"|>,\\\"TeXAssistantTemplate\\\"]\\)\"", HoldForm], 
      TraditionalForm], None}},
  FrameStyle->Thickness[0.004],
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  LabelStyle->Directive[FontFamily -> "Times", FontSize -> 16],
  Method->{
   "AxisPadding" -> Scaled[0.02], "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "DefaultPlotStyle" -> {
      Directive[
       RGBColor[0.368417, 0.506779, 0.709798], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.880722, 0.611041, 0.142051], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.560181, 0.691569, 0.194885], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.922526, 0.385626, 0.209179], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.528488, 0.470624, 0.701351], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.772079, 0.431554, 0.102387], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.363898, 0.618501, 0.782349], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[1, 0.75, 0], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.647624, 0.37816, 0.614037], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.571589, 0.586483, 0.], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.915, 0.3325, 0.2125], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.9728288904374106, 0.621644452187053, 0.07336199581899142], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.736782672705901, 0.358, 0.5030266573755369], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], 
       AbsoluteThickness[1.6]]}, "DomainPadding" -> Scaled[0.02], 
    "PointSizeFunction" -> "SmallPointSize", "RangePadding" -> Scaled[0.05], 
    "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> True, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& )}},
  PlotRange->{{3.03, 3.48}, {0.065, 0.35}},
  PlotRangeClipping->True,
  PlotRangePadding->{{None, None}, {None, None}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{
  3.887453170974105*^9, 3.887453288745363*^9, 3.887454234640769*^9, {
   3.887454285323175*^9, 3.887454305323058*^9}, 3.8874543521230183`*^9, 
   3.887454494386121*^9, 3.8874547357675037`*^9, 3.8874548153365507`*^9, 
   3.887455763533781*^9, 3.88752379396257*^9, 3.887523858899837*^9, 
   3.887523906284834*^9, 3.891090730146121*^9},
 CellLabel->"Out[6]=",ExpressionUUID->"2d4c5d06-6886-4d34-8dd4-fcc7c718e292"]
}, Open  ]]
},
WindowToolbars->"MultipurposeBar",
CellGrouping->Manual,
WindowSize->{1051, 661},
WindowMargins->{{21, Automatic}, {Automatic, 28}},
PrivateNotebookOptions->{"VersionedStylesheet"->{"Default.nb"[8.] -> False}},
ShowCellLabel->True,
ShowCellTags->False,
FrontEndVersion->"13.2 for Mac OS X x86 (64-bit) (November 18, 2022)",
StyleDefinitions->"Default.nb",
ExpressionUUID->"0b608455-9ff0-4ada-b077-9a17606ae6f6"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[558, 20, 489, 10, 53, "Text",ExpressionUUID->"38ec253e-1b44-4e36-a8c5-d557cead260a"],
Cell[1050, 32, 332, 5, 67, "Section",ExpressionUUID->"66d6ba2b-47f8-4d2b-a950-7052c61932c1"],
Cell[1385, 39, 1362, 34, 118, "Text",ExpressionUUID->"db95312e-36a0-492f-b058-787d66ce8ffa"],
Cell[2750, 75, 1400, 37, 52, "Input",ExpressionUUID->"9d139eb4-71d0-4837-8f10-8feab0fa82b4"],
Cell[4153, 114, 1185, 26, 30, "Input",ExpressionUUID->"f530a849-d9f6-4f63-9019-36a53df1f7c4"],
Cell[5341, 142, 656, 10, 53, "Text",ExpressionUUID->"6a483d6b-d5b3-4a16-b3c9-df1c78ec9654"],
Cell[6000, 154, 1134, 21, 54, "Input",ExpressionUUID->"15bb367d-95ae-4deb-977a-64138d3c7055"],
Cell[7137, 177, 423, 7, 53, "Text",ExpressionUUID->"a2bc5286-e70f-4a92-99dd-da046c3645b3"],
Cell[7563, 186, 365, 8, 33, "Input",ExpressionUUID->"a4d0dc5a-8059-4108-ac8e-50fd2c4c854c"],
Cell[7931, 196, 1257, 29, 55, "Text",ExpressionUUID->"dc79387d-4d83-4e82-b728-78f4965401e7"],
Cell[CellGroupData[{
Cell[9213, 229, 1889, 42, 73, "Input",ExpressionUUID->"2be82904-b6a6-4717-8d2d-1db439c5c7d9"],
Cell[11105, 273, 11185, 223, 271, "Output",ExpressionUUID->"2d4c5d06-6886-4d34-8dd4-fcc7c718e292"]
}, Open  ]]
}
]
*)

